import 'dart:io';

import 'package:excel/excel.dart';
import 'package:file_picker/file_picker.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:go_router/go_router.dart';
import 'package:path_provider/path_provider.dart';

class OrderList extends StatefulWidget {
  const OrderList({super.key});

  @override
  State<OrderList> createState() => _OrderListState();
}

class _OrderListState extends State<OrderList> {
  final List lst = [];
  List<String> headers = [];
  List<List<dynamic>> data = [];
  late Excel _excel;
  ScrollController scrollController = ScrollController();
  final TextEditingController _logComController =
      TextEditingController(text: "");

  @override
  Widget build(BuildContext context) {
    return Scaffold(
        appBar: AppBar(
          backgroundColor: Colors.white,
          title: const Text("test"),
          actions: [
            IconButton(
                onPressed: () {
                  importExcelFile();
                },
                icon: const Icon(Icons.add_circle)),
            IconButton(
                onPressed: () {
                  exportExcelFile();
                },
                icon: const Icon(Icons.output))
          ],
        ),
        body: Container(
          width: double.infinity,
          // color: Colors.white,
          padding: const EdgeInsets.all(20),
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.center,
            children: [
              Card(
                color: Colors.white,
                margin: EdgeInsets.zero,
                child: headers.isNotEmpty
                    ? /*Scrollbar(
                        // controller: scrollController,
                        child:*/
                    SingleChildScrollView(
                        scrollDirection: Axis.horizontal,
                        padding: const EdgeInsets.all(12.0),
                        child: DataTable(
                          columns: headers.map((el) {
                            return DataColumn(label: Text(el));
                          }).toList(),
                          rows: data.asMap().entries.map((row) {
                            return DataRow(
                                cells: row.value.asMap().entries.map((col) {
                              String colTitle = headers[col.key];
                              return DataCell(colTitle == "物流名称"
                                  ? Row(
                                      children: [
                                        Text("${col.value}"),
                                        IconButton(
                                            // padding: EdgeInsets.all(2),
                                            iconSize: 12,
                                            onPressed: () {
                                              _logComController.text =
                                                  data[row.key][col.key]
                                                      .toString();
                                              showDialog(
                                                  context: context,
                                                  builder: (BuildContext
                                                          context) =>
                                                      AlertDialog(
                                                        // icon: const Icon(Icons.edit),
                                                        title: const Text(
                                                            "填写物流公司"),
                                                        content: Column(
                                                          mainAxisSize:
                                                              MainAxisSize.min,
                                                          children: [
                                                            TextField(
                                                              decoration:
                                                                  const InputDecoration(
                                                                      labelText:
                                                                          "物流公司"),
                                                              controller:
                                                                  _logComController,
                                                            )
                                                          ],
                                                        ),
                                                        actions: [
                                                          ElevatedButton(
                                                              onPressed: () {
                                                                context.pop();
                                                              },
                                                              child: const Text(
                                                                  "取消")),
                                                          ElevatedButton(
                                                              onPressed: () {
                                                                String
                                                                    logisticsCom =
                                                                    _logComController
                                                                        .text;
                                                                if (logisticsCom
                                                                    .isEmpty) {
                                                                  ScaffoldMessenger.of(
                                                                          context)
                                                                      .showSnackBar(const SnackBar(
                                                                          content:
                                                                              Text("请输入物流公司")));
                                                                  return;
                                                                }
                                                                final _data =
                                                                    data;
                                                                data[row.key][col
                                                                        .key] =
                                                                    logisticsCom;
                                                                setState(() {
                                                                  data = _data;
                                                                });
                                                                context.pop();
                                                              },
                                                              child: const Text(
                                                                  "确认")),
                                                        ],
                                                      ));
                                            },
                                            icon: const Icon(Icons.edit))
                                      ],
                                    )
                                  : colTitle == "物流信息"
                                      ? ElevatedButton(
                                          onPressed: () {
                                            String orderNumber =
                                                data[row.key][2].toString();
                                            String orderPayWay =
                                                data[row.key][15].toString();
                                            if (orderPayWay.isEmpty ||
                                                orderNumber.isEmpty) {
                                              ScaffoldMessenger.of(context)
                                                  .showSnackBar(const SnackBar(
                                                      content: Text("该行数据有误")));
                                              return;
                                            }
                                            context.pushNamed("logistics",
                                                queryParameters: {
                                                  "orderNumber": data[row.key]
                                                          [2]
                                                      .toString(),
                                                  "orderPayWay": data[row.key]
                                                          [15]
                                                      .toString(),
                                                });
                                          },
                                          child: const Text("填写"),
                                        )
                                      : Text("${col.value}"));
                            }).toList());
                          }).toList(),
                        ),
                      )
                    /*)*/
                    : const Text("empty"),
              )
            ],
          ),
        ));
  }

  Future<String> importExcelFile() async {
    FilePickerResult? result = await FilePicker.platform
        .pickFiles(type: FileType.custom, allowedExtensions: ["xlsx", "xls"]);
    if (result != null) {
      File file = File(result.files.single.path!);
      var bytes = file.readAsBytesSync();
      Excel excel = Excel.decodeBytes(bytes);
      _excel = excel;
      String tableKey = excel.tables.keys.first;
      List<String> _headers = excel.tables[tableKey]?.rows.first.map((el) {
            return el?.value.toString() ?? "";
          }).toList() ??
          [];
      List<List<dynamic>> _data = excel.tables[tableKey]?.rows
              .where((el) => (el.first?.value?.toString() ?? "").isNotEmpty)
              .toList()
              .sublist(1)
              .map((row) {
            return row.map((col) {
              return col?.value ?? "";
            }).toList();
          }).toList() ??
          [];
      setState(() {
        headers = _headers;
        data = _data;
      });
    } else {
      //   取消选择
    }
    return "";
  }

  exportExcelFile() async {
    data.asMap().entries.forEach((row) {
      row.value.asMap().entries.forEach((col) {
        int rowIndex = row.key + 1;
        int colIndex = col.key;
        if (colIndex == 11 || colIndex == 12) {
          _excel.updateCell(
              "订单列表",
              CellIndex.indexByColumnRow(
                  columnIndex: colIndex, rowIndex: rowIndex),
              TextCellValue(col.value.toString()));
        }
      });
    });
    var fileBytes = _excel.save();
    // var directory = await getApplicationDocumentsDirectory();
    File(
        "C:\\Users\\ayaya\\Desktop\\导出订单${DateTime.now().millisecondsSinceEpoch}.xlsx")
      ..createSync(recursive: true)
      ..writeAsBytesSync(fileBytes!);
    ScaffoldMessenger.of(context).showSnackBar(const SnackBar(
      content: Text("导出文件成功"),
      backgroundColor: Colors.green,
    ));
  }
}
